Castable

Trait Castable 

pub trait Castable {
    // Required method
    fn castable<T: ?Sized + 'static>() -> bool;
}
Whether this concrete type can be cast to a given trait object

Required Methods

fn castable<T: ?Sized + 'static>() -> bool

Whether this type is castable to the given trait object

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<U: ?Sized + 'static> Castable for U